TRANSLATOR_GENERIC = 1
TRANSLATOR_BEAUTIFY = 2
TRANSLATOR_MYSQL = 3
TRANSLATOR_SQLITE = 4

PARAM_NONE = 1
PARAM_NUM = 2
PARAM_ASSOC = 3

class Config :

    translator = TRANSLATOR_GENERIC
    binding = PARAM_NUM

    table = ''
